package media

import (
	"eta/eta_mini_ht_api/common/component/config"
	"eta/eta_mini_ht_api/common/component/es"
	logger "eta/eta_mini_ht_api/common/component/log"
	"eta/eta_mini_ht_api/common/contants"
	"eta/eta_mini_ht_api/common/utils/page"
	chartService "eta/eta_mini_ht_api/domian/media"
)

type ChartInfo struct {
	ChartInfoId int
	ChartName   string
	ChartImage  string
	UniqueCode  string
}

const (
	ESColumn = "chartName"
)

var (
	sortField = []string{"_score:desc"}
	htConfig  = config.GetConfig(contants.HT).(*config.HTBizConfig)
)

func elastic() *es.ESClient {
	return es.GetInstance()
}
func AddChartToEs(chartInfo ChartInfo) {
	success := chartService.AddChartToEs(chartService.EsChartInfo{
		ChartInfoId: chartInfo.ChartInfoId,
		ChartName:   chartInfo.ChartName,
		ChartImage:  chartInfo.ChartImage,
		UniqueCode:  chartInfo.UniqueCode,
	})
	if !success {
		logger.Error("新增图表到ES失败, chartInfoId:%d,uniqueCode:%s", chartInfo.ChartInfoId, chartInfo.UniqueCode)
	}
}
func SearchChartList(key string, ids []int, pageInfo page.PageInfo) (charts []ChartInfo, err error) {
	offset := page.StartIndex(pageInfo.Current, pageInfo.PageSize)
	esChart, err := chartService.SearchChartList(key, ids, offset, pageInfo.PageSize)
	if err != nil {
		return
	}
	for _, chart := range esChart {
		charts = append(charts, convertChartInfo(chart))
	}
	return
}
func SearchAllChartList(key string, ids []int) (charts []ChartInfo, err error) {
	esChart, err := chartService.SearchAllChartList(key, ids)
	if err != nil {
		return
	}
	for _, chart := range esChart {
		charts = append(charts, convertChartInfo(chart))
	}
	return
}

func UpdateChartImage(image string, id int) bool {
	return chartService.UpdateChartImage(image, id)
}

func GetChartById(chartInfoId int) (info ChartInfo, err error) {
	chart, err := chartService.GetChartById(chartInfoId)
	if err != nil {
		return
	}
	info = convertChartInfo(chart)
	return
}
func convertChartInfo(chart chartService.EsChartInfo) ChartInfo {
	return ChartInfo{
		ChartInfoId: chart.ChartInfoId,
		ChartName:   chart.ChartName,
		ChartImage:  chart.ChartImage,
		UniqueCode:  chart.UniqueCode,
	}
}
